/* BdfServer_HtmlProducers - Copyright (c) 2012-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.text.ParseException;
import net.fichotheque.ExistingSubsetException;
import net.fichotheque.SubsetKey;
import net.fichotheque.thesaurus.ThesaurusEditor;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadata;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusCreationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "ThesaurusCreation";
    public final static String COMMANDKEY = "_ THS-01";
    public final static String NEWTHESAURUS_PARAMNAME = "newthesaurus";
    public final static String THESAURUSTYPE_PARAMNAME = "thesaurustype";
    private SubsetKey newThesaurusKey;
    private short thesaurusType;

    public ThesaurusCreationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        try {
            ThesaurusEditor thesaurusEditor = editSession.getFichothequeEditor().createThesaurus(newThesaurusKey, thesaurusType);
            if (thesaurusType != ThesaurusMetadata.BABELIEN_TYPE) {
                thesaurusEditor.getThesaurusMetadataEditor().setAuthorizedLangs(bdfServer.getLangConfiguration().getWorkingLangs());
            }
            putResultObject(THESAURUS_OBJ, thesaurusEditor.getThesaurus());
            setDone("_ done.thesaurus.thesauruscreation", newThesaurusKey.toString());
        } catch (ExistingSubsetException ese) {
            throw new ShouldNotOccurException("test before ExistingSubsetException");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        String newThesaurusName = getMandatory(NEWTHESAURUS_PARAMNAME);
        newThesaurusName = newThesaurusName.trim();
        if (newThesaurusName.length() == 0) {
            setError("_ error.empty.thesaurusname", newThesaurusName);
            return false;
        }
        try {
            newThesaurusKey = SubsetKey.parse(SubsetKey.CATEGORY_THESAURUS, newThesaurusName);
            if (bdfServer.getFichotheque().getSubset(newThesaurusKey) != null) {
                setError("_ error.existing.thesaurus", newThesaurusKey.toString());
                return false;
            }
        } catch (ParseException pe) {
            setError("_ error.wrong.thesaurusname", newThesaurusName);
            return false;
        }
        String thesaurusTypeString = getMandatory(THESAURUSTYPE_PARAMNAME);
        try {
            thesaurusType = ThesaurusUtils.thesaurusTypeToShort(thesaurusTypeString);
        } catch (IllegalArgumentException iae) {
            throw new BdfInstructionException(BdfInstructionUtils.unknownParameterValue(THESAURUSTYPE_PARAMNAME, thesaurusTypeString));
        }
        return true;
    }

}
