/* BdfServer_HtmlProducers - Copyright (c) 2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.corpus;

import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.domains.CorpusDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.html.BdfHtmlUtils;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.MiscJsLibs;
import net.fichotheque.SubsetKey;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.JsObject;


/**
 *
 * @author Vincent Calame
 */
public class RemovedListHtmlProducer extends BdfServerHtmlProducer {

    private final PermissionSummary permissionSummary;
    private final Corpus corpus;

    public RemovedListHtmlProducer(ProducerParameters producerParameters, Corpus corpus) {
        super(producerParameters);
        addThemeCss("restore.css");
        addJsLib(MiscJsLibs.RESTORE);
        this.corpus = corpus;
        this.permissionSummary = producerParameters.getPermissionSummary();
    }

    @Override
    public void printHtml() {

        SubsetKey subsetKey = corpus.getSubsetKey();
        String clientId = generateId();
        JsObject args = JsObject.init()
                .put("clientId", clientId)
                .put("subsetKey", subsetKey.toString())
                .put("subsetCategory", subsetKey.getCategoryString())
                .put("subsetName", subsetKey.getSubsetName());
        start();
        BdfHtmlUtils.printSubsetHeader(this, bdfServer, bdfUser, permissionSummary, corpus, CorpusDomain.CORPUS_PHRASESFORM_PAGE);
        CorpusHtmlUtils.printCorpusToolbar(this, corpus, CorpusDomain.REMOVEDLIST_PAGE);
        printCommandMessageUnit();
        this
                .SCRIPT()
                .__jsObject("Restore.ARGS", args)
                ._SCRIPT();
        this
                .DIV(HA.id(clientId))
                ._DIV();
        end();
    }

}
