/* BdfServer_HtmlProducers - Copyright (c) 2019-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.edition;

import fr.exemole.bdfserver.html.consumers.Button;
import net.fichotheque.SubsetKey;
import net.mapeadores.util.exceptions.SwitchException;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlPrinter;


/**
 *
 * @author Vincent Calame
 */
public final class EditionHtmlUtils {

    private EditionHtmlUtils() {

    }

    public static boolean printFicheHeader(HtmlPrinter hp, String title, boolean discarded, String formId) {
        hp
                .HEADER("subset-ItemHeader edition-Header")
                .H1(HA.classes(discarded, "subset-Discarded"))
                .__escape(title)
                ._H1()
                .DIV("edition-Submit")
                .__(Button.submit("action-Save", "_ link.global.ok").formId(formId).ficheForm(true))
                ._DIV()
                ._HEADER();
        return true;
    }

    public static String getSatelliteAllErrMessageKey(short subsetCategory) {
        switch (subsetCategory) {
            case SubsetKey.CATEGORY_CORPUS:
                return "_ error.edition.satelliteall_corpus";
            case SubsetKey.CATEGORY_THESAURUS:
                return "_ error.edition.satelliteall_thesaurus";
            default:
                throw new SwitchException("Unknown masterCategory: " + subsetCategory);
        }
    }

    public static String getSatelliteInfoMessageKey(short subsetCategory) {
        switch (subsetCategory) {
            case SubsetKey.CATEGORY_CORPUS:
                return "_ info.edition.satellite_corpus";
            case SubsetKey.CATEGORY_THESAURUS:
                return "_ info.edition.satellite_thesaurus";
            default:
                throw new SwitchException("Unknown masterCategory: " + subsetCategory);
        }
    }

    public static String getMasterSelectMessageKey(short subsetCategory) {
        switch (subsetCategory) {
            case SubsetKey.CATEGORY_CORPUS:
                return "_ label.edition.masterselect_corpus";
            case SubsetKey.CATEGORY_THESAURUS:
                return "_ label.edition.masterselect_thesaurus";
            default:
                throw new SwitchException("Unknown masterCategory: " + subsetCategory);
        }
    }

    public static String getMasterSubsetItemMessageKey(short subsetCategory) {
        switch (subsetCategory) {
            case SubsetKey.CATEGORY_CORPUS:
                return "_ label.edition.master_fiche";
            case SubsetKey.CATEGORY_THESAURUS:
                return "_ label.edition.master_motcle";
            default:
                throw new SwitchException("Unknown masterCategory: " + subsetCategory);
        }
    }


}
