/* BdfServer_HtmlProducers - Copyright (c) 2017-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.misc;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.MiscJsLibs;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.SubsetKey;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.FicheMeta;
import net.fichotheque.utils.CorpusMetadataUtils;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.JsObject;


/**
 *
 * @author Vincent Calame
 */
public class HistoryHtmlProducer extends BdfServerHtmlProducer {

    private final Subset subset;
    private final int id;

    public HistoryHtmlProducer(ProducerParameters producerParameters, Subset subset, int id) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), subset, id);
    }

    public HistoryHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, Subset subset, int id) {
        super(bdfServer, bdfUser);
        this.subset = subset;
        this.id = id;
        addThemeCss("history.css");
        addJsLib(MiscJsLibs.HISTORY);
    }

    @Override
    public void printHtml() {
        SubsetItem subsetItem = subset.getSubsetItemById(id);
        SubsetKey subsetKey = subset.getSubsetKey();
        String clientId = generateId();
        JsObject args = JsObject.init()
                .put("clientId", clientId)
                .put("subsetKey", subsetKey.toString())
                .put("subsetCategory", subsetKey.getCategoryString())
                .put("subsetName", subsetKey.getSubsetName())
                .put("id", id)
                .put("title", getSubsetItemTitle(subsetItem))
                .put("discarded", isDiscarded(subsetItem));
        start();
        this
                .SCRIPT()
                .__jsObject("History.ARGS", args)
                ._SCRIPT();
        this
                .DIV(HA.id(clientId))
                ._DIV();
        end();
    }


    private String getSubsetItemTitle(SubsetItem subsetItem) {
        if (subset instanceof Corpus) {
            Corpus corpus = (Corpus) subset;
            if (subsetItem != null) {
                return CorpusMetadataUtils.getFicheTitle((FicheMeta) subsetItem, workingLang, formatLocale);
            } else {
                return FichothequeUtils.getNumberPhrase(corpus, id, "fiche", workingLang, formatLocale);
            }
        }
        return "";
    }

    private Boolean isDiscarded(SubsetItem subsetItem) {
        if (subsetItem == null) {
            return Boolean.TRUE;
        } else if (subsetItem instanceof FicheMeta) {
            return ((FicheMeta) subsetItem).isDiscarded();
        } else {
            return Boolean.FALSE;
        }
    }

}
