/* BdfServer_HtmlProducers - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.pioche;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.domains.PiocheDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.MiscJsLibs;
import java.util.List;
import net.fichotheque.Subset;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.html.HA;


/**
 *
 * @author Vincent Calame
 */
public class FichePiocheHtmlProducer extends BdfServerHtmlProducer {

    private final PiocheParameters piocheParameters;
    private final List<Subset> corpusList;

    public FichePiocheHtmlProducer(ProducerParameters producerParameters, PiocheParameters piocheParameters) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), piocheParameters);
    }

    public FichePiocheHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, PiocheParameters piocheParameters) {
        super(bdfServer, bdfUser);
        this.piocheParameters = piocheParameters;
        corpusList = piocheParameters.getSubsetList();
        addThemeCss("pioche.css");
        addJsLib(MiscJsLibs.PIOCHE);
    }

    @Override
    public void printHtml() {
        String clientId = generateId();
        String wanted = PiocheDomain.CODE_ID_WANTED;
        if ((corpusList != null) && (corpusList.size() == 1)) {
            wanted = PiocheDomain.ID_WANTED;
        }
        int total = getTotal();
        startLoc("_ title.pioche.fiche");
        PiocheHtmlUtils.printJsObject(this, clientId, piocheParameters, total, " – ", wanted, PiocheDomain.FICHE_JSON, PiocheHtmlUtils.getSubsetsString(corpusList), null);
        this
                .DIV(HA.id(clientId).classes("pioche-Client"))
                ._DIV();
        end();
    }

    private int getTotal() {
        int count = 0;
        if (corpusList == null) {
            for (Corpus corpus : fichotheque.getCorpusList()) {
                count = count + corpus.size();
            }
        } else {
            for (Subset subset : corpusList) {
                count = count + subset.size();
            }
        }
        return count;
    }

}
