/* BdfServer_JsonProducers - Copyright (c) 2017-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.corpus;

import fr.exemole.bdfserver.api.ui.FieldUi;
import fr.exemole.bdfserver.api.ui.UiComponent;
import fr.exemole.bdfserver.api.ui.UiComponents;
import java.io.IOException;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.metadata.CorpusField;
import net.fichotheque.corpus.metadata.CorpusMetadata;
import net.fichotheque.corpus.metadata.FieldKey;
import net.fichotheque.utils.CorpusMetadataUtils;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProperty;
import net.mapeadores.util.localisation.Lang;


/**
 *
 * @author Vincent Calame
 */
public class UiJsonProperty implements JsonProperty {

    private final Corpus corpus;
    private final Lang lang;
    private final UiComponents uiComponents;

    public UiJsonProperty(Corpus corpus, Lang lang, UiComponents uiComponents) {
        this.corpus = corpus;
        this.lang = lang;
        this.uiComponents = uiComponents;
    }

    @Override
    public void write(JSONWriter jw) throws IOException {
        CorpusMetadata corpusMetadata = corpus.getCorpusMetadata();
        jw.key("ui");
        jw.object();
        {
            jw.key("componentArray");
            jw.array();
            for (UiComponent uiComponent : uiComponents.getUiComponentList()) {
                if (uiComponent instanceof FieldUi) {
                    CorpusField corpusField = corpusMetadata.getCorpusField(((FieldUi) uiComponent).getFieldKey());
                    if (corpusField != null) {
                        writeCorpusField(jw, corpusField);
                    }
                }
            }
            jw.endArray();
        }
        jw.endObject();
    }

    private void writeCorpusField(JSONWriter jw, CorpusField corpusField) throws IOException {
        FieldKey fieldKey = corpusField.getFieldKey();
        jw.object();
        {
            jw.key("key")
                    .value(fieldKey.toString());
            jw.key("patternType");
            if (fieldKey.isSectionFieldKey()) {
                jw.value("section");
            } else if ((fieldKey.equals(FieldKey.ID)) || (fieldKey.equals(FieldKey.TITRE))) {
                jw.value("value");
            } else {
                jw.value(CorpusMetadataUtils.ficheItemTypeToString(corpusField.getFicheItemType()));
            }
            jw.key("title")
                    .value(CorpusMetadataUtils.getFieldTitle(corpusField, lang));
        }
        jw.endObject();
    }

}
