/* global BDF,$$ */
/**
 * Objet global définissant l'espace de nom Pioche
 * 
 * @namespace Pioche
 */
var Pioche = {};

Pioche.ARGS = {
  appelant: "",  
  limit: -1,
  count: -1,
  separator: "",
  wanted: "",
  croisement: "",
  json: "",
  subsets: "",
  param: "",
  motcleselectoptions: ""
};

Pioche.init = function (args) {
    var piocheId = BDF.generateId();
    var jsonData = null;
    $$(args.clientId).html(BDF.render("pioche:client", {
        args: args,
        piocheId: piocheId
    }));
    _$$("confirm").click(_updateAppelant);
    _$$("cancel").click(function () {
        window.close();
    });
    _$$("select", "available").click(function () {
        _selection(this);
    }).keydown(function (event) {
         if (event.key === "Enter") {
            _selection(this);
        }
    });
    _$$("select", "selected").click(function () {
        _deselection(this);
    }).keydown(function (event) {
         if (event.key === "Enter") {
            _deselection(this);
        }
    });
    if (args.limit === 1) {
        _$$("select", "selected").attr("size", "2");
    }
    if ((args.count > -1) && (args.count < 31)) {
        _$$("header").addClass("hidden");
        _$$("form").ajaxSubmit({
            dataType:  'json',
            success:   _processJson
        });
    } else {
        _$$("form").ajaxForm({
            dataType:  'json',
            success:   function (data, textStatus, jqXHR, $form) {
                _processJson(data);
            }
        });
        _$$("qinput").focus();
    }
    
    function _$$(id) {
        if (arguments.length > 1) {
            id = Array.from(arguments).join("_");
        }
        return $$(piocheId, id);
    }
    
    function _updateAppelant() {
        this.disabled = true;
        let limit = args.limit;
        let newValue = "";
        _$$("select", "selected").find("option").each(function (index, option) {
            newValue = newValue + option.value;
            if (limit !== 1) newValue = newValue + "; ";
        });
        let element = window.opener.document.getElementById(args.appelant);
        if (limit !== 1) {
            let currentValue = element.value;
            if (_testSemicolon(currentValue)) {
                currentValue = currentValue + "; ";
            }
            newValue = currentValue + newValue;
        }
        element.value = newValue;
        window.close();
    }

    function _testSemicolon(currentText) {
        let size = currentText.length;
        if (size === 0) return false;
        for (let i = size-1;i >= 0;i --) {
            let carac = currentText.charAt(i);
            if (carac !== " ") {
                if (carac === ";") return false;
                else return true;
            }
        }
        return false;
    }

    function _processJson(data) {
        jsonData = data;
        let length = data.length;
        _$$("count", "available").text(length);
        let $tabs = _$$("tabs", "available").empty();
        if (length === 0) {
            alert(BDF.Loc.get("_ warning.pioche.emptyresult"));
        } else {
            let seuilvisibilite = Math.ceil(length/10);
            if (seuilvisibilite > 1) {
                for (let k = 0; k < seuilvisibilite;k++) {
                   $tabs.append(BDF.render("pioche:tab", {
                       piocheId: piocheId,
                       number: k,
                       disabled: (k === 0)
                   }));
                   _$$("tab", k).click(function () {
                       _activeTab(k, $(this));
                   });
                }
                _activeTab(0, _$$("tab", 0));
            } else {
                _updateAvailable(0);
            }
        }
    }

    function _activeTab(dizaine, $tab) {
        BDF.$({role: "tab"}).prop("disabled", false);
        $tab.prop("disabled", true);
        _updateAvailable(dizaine);
    }

    function _updateAvailable(dizaine) {
        let $avalaibleSelect = _$$("select", "available").empty();
        let plafond = Math.min(jsonData.length, 10*(dizaine + 1));
        let plancher = 10*dizaine;
        let wanted = args.wanted;
        for (let k = plancher; k < plafond;k ++) {
            let object = jsonData.array[k];
            let key = "";
            let text = "";
            switch(wanted) {
                case "id":
                    key = object.id;
                    if (object.code) {
                        text = object.code;
                    } else {
                        text = "" + key;
                    }
                    break;
                case "code-id":
                    if (object.code) {
                        key = object.code;
                    } else {
                        key = object.id;
                    }
                    text = "" + key;
                    break;
                case "code-title":
                     if (object.code) {
                        key = object.code;
                        text = "" + key;
                    } else if (object.title) {
                        key = object.title;
                        text = "";
                    } else {
                        key = object.id;
                        text = "" + key;
                    }
                    break;
            }
            if (object.title) {
                if (text) {
                    text = text + args.separator + object.title;
                } else {
                    text = object.title;
                }
            }
            if (object.description) {
                text = text + " (" + object.description + ")";
            }
            $avalaibleSelect.append(BDF.render("pioche:option", {
                value: key,
                text: text
            }));
        }
    }

    function _selection(select) {
        let idx = select.selectedIndex;
        if (idx === -1) return;
        let option = select.options[idx];
        let value = option.value;
        let $selectedSelect = _$$("select", "selected");
        for (let opt of $selectedSelect[0].options) {
            if (opt.value === value) return;
        }
        $selectedSelect.append(BDF.render("pioche:option", {
            value: value,
            text: option.text
        }));
        _checkSelect();
    }

    function _checkSelect() {
        let count = _$$("select", "selected").find("option").length;
        let limit = args.limit;
        if((limit !== -1) && (count >= limit)) {
            _$$("select", "available").prop("disabled", true);
        }
        else {
            _$$("select", "available").prop("disabled", false);
        }
        _$$("confirm").prop("disabled", (count === 0));
        _$$("count", "selected").text(count);
    }

    function _deselection(select) {
        let idx = select.selectedIndex;
        if (idx === -1) return;
        select.remove(idx);
        select.selectedIndex = -1;
        _checkSelect();
    }
};

$(function () {
    BDF.initTemplates();
    Pioche.init(Pioche.ARGS);
});
