/* FichothequeLib_API - Copyright (c) 2009-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.format;

import java.util.List;
import java.util.function.Predicate;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.exportation.table.CellEngineProvider;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.extraction.ExtractionEngine;
import net.fichotheque.pointeurs.SubsetItemPointeur;
import net.mapeadores.util.localisation.LangContext;


/**
 * Source de données d'un formatage.
 *
 *
 * @author Vincent Calame
 */
public interface FormatSource {

    public SubsetItemPointeur getSubsetItemPointeur();

    public ExtractionContext getExtractionContext();

    public Predicate<SubsetItem> getGlobalSelectPredicate();

    public FormatContext getFormatContext();

    public CellEngineProvider getCellEngineProvider();

    public ExtractionEngine getExtractionEngine();

    public History getHistory();

    public default LangContext getLangContext() {
        return getExtractionContext().getLangContext();
    }

    public default Predicate<Subset> getSubsetAccessPredicate() {
        return getExtractionContext().getSubsetAccessPredicate();
    }


    public interface History {

        public List<String> getPreviousFormatList();

    }

}
