/* FichothequeLib_Tools - Copyright (c) 2016-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.exportation.table.dom;

import java.text.ParseException;
import net.mapeadores.util.xml.DomMessages;
import net.fichotheque.tools.exportation.table.TableExportDefBuilder;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.ElementHandler;
import net.mapeadores.util.xml.XMLUtils;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class TableExportDefDOMReader {

    private final TableExportDefBuilder tableExportDefBuilder;
    private final MessageHandler messageHandler;

    public TableExportDefDOMReader(TableExportDefBuilder tableExportDefBuilder, MessageHandler messageHandler) {
        this.tableExportDefBuilder = tableExportDefBuilder;
        this.messageHandler = messageHandler;
    }

    public void readTableExportDef(Element element) {
        RootHandler rootHandler = new RootHandler();
        DOMUtils.readChildren(element, rootHandler);
    }


    private class RootHandler implements ElementHandler {

        private RootHandler() {
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("label")) {
                try {
                    LabelUtils.readLabel(element, tableExportDefBuilder);
                } catch (ParseException ile) {
                    DomMessages.wrongLangAttribute(messageHandler, tagName, element.getAttribute("xml:lang"));
                }
            } else if (tagName.equals("langs")) {
                String langMode = element.getAttribute("mode");
                if (langMode.length() > 0) {
                    tableExportDefBuilder.setLangMode(langMode);
                }
                LangsHandler langsHandler = new LangsHandler();
                DOMUtils.readChildren(element, langsHandler);
            } else if (tagName.equals("attr")) {
                AttributeUtils.readAttrElement(tableExportDefBuilder.getAttributesBuilder(), element);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }


    private class LangsHandler implements ElementHandler {

        private LangsHandler() {

        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("lang")) {
                String text = XMLUtils.getData(element);
                try {
                    Lang lang = Lang.parse(text);
                    tableExportDefBuilder.addLang(lang);
                } catch (ParseException pe) {
                    DomMessages.wrongElementValue(messageHandler, tagName, text);
                }
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }


}
