/* FichothequeLib_Tools - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.Collections;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.DocumentFilter;
import net.fichotheque.extraction.def.ExtraitAddendaDef;
import net.fichotheque.utils.SelectionUtils;
import net.fichotheque.selection.DocumentQuery;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitAddendaDefBuilder {

    private DocumentFilter documentFilter;
    private String extraitName = null;
    private String tagName = ExtractionConstants.EXTRAITADDENDA_DEFAULT_TAGNAME;
    private List<DocumentQuery> documentQueryList = SelectionUtils.EMPTY_DOCUMENTQUERYLIST;

    public ExtraitAddendaDefBuilder(DocumentFilter documentFilter) {
        if (documentFilter == null) {
            throw new IllegalArgumentException("documentFilter is null");
        }
        this.documentFilter = documentFilter;
    }

    public ExtraitAddendaDefBuilder setDocumentFilter(DocumentFilter DocumentFilter) {
        if (documentFilter == null) {
            throw new IllegalArgumentException("documentFilter is null");
        }
        this.documentFilter = DocumentFilter;
        return this;
    }

    public ExtraitAddendaDefBuilder setExtraitName(String extraitName) {
        if ((extraitName != null) && (extraitName.length() == 0)) {
            extraitName = null;
        }
        this.extraitName = extraitName;
        return this;
    }

    public ExtraitAddendaDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, ExtractionConstants.EXTRAITADDENDA_DEFAULT_TAGNAME);
        return this;
    }

    public ExtraitAddendaDefBuilder setDocumentQueryList(List<DocumentQuery> list) {
        this.documentQueryList = list;
        return this;
    }

    public ExtraitAddendaDefBuilder setDocumentQueryList(DocumentQuery documentQuery) {
        this.documentQueryList = Collections.singletonList(documentQuery);
        return this;
    }

    public ExtraitAddendaDef toExtraitAddendaDef() {
        return new InternalExtraitAddendaDef(documentFilter, extraitName, tagName, documentQueryList);
    }

    public static ExtraitAddendaDefBuilder init(DocumentFilter documentFilter) {
        return new ExtraitAddendaDefBuilder(documentFilter);
    }


    private static class InternalExtraitAddendaDef implements ExtraitAddendaDef {

        private final DocumentFilter documentFilter;
        private final String extraitName;
        private final String tagName;
        private final List<DocumentQuery> documentQueryList;

        private InternalExtraitAddendaDef(DocumentFilter documentFilter, String extraitName, String tagName, List<DocumentQuery> documentQueryList) {
            this.tagName = tagName;
            this.extraitName = extraitName;
            this.documentFilter = documentFilter;
            this.documentQueryList = documentQueryList;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public String getExtraitName() {
            return extraitName;
        }

        @Override
        public DocumentFilter getDocumentFilter() {
            return documentFilter;
        }

        @Override
        public List<DocumentQuery> getDocumentQueryList() {
            return documentQueryList;
        }

    }

}
