/* FichothequeLib_Tools - Copyright (c) 2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.selection;

import java.util.ArrayList;
import java.util.List;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.selection.FichothequeQuery;
import net.fichotheque.selection.MotcleQuery;
import net.fichotheque.utils.SelectionUtils;


/**
 *
 * @author Vincent Calame
 */
public class FichothequeQueryBuilder {

    private final List<FicheQuery> ficheQueryList = new ArrayList<FicheQuery>();
    private final List<MotcleQuery> motcleQueryList = new ArrayList<MotcleQuery>();

    public FichothequeQueryBuilder() {

    }

    public FichothequeQueryBuilder addFicheQuery(FicheQuery ficheQuery) {
        if (!SelectionUtils.isEmpty(ficheQuery)) {
            ficheQueryList.add(ficheQuery);
        }
        return this;
    }

    public FichothequeQueryBuilder addMotcleQuery(MotcleQuery motcleQuery) {
        if (!SelectionUtils.isEmpty(motcleQuery)) {
            motcleQueryList.add(motcleQuery);
        }
        return this;
    }

    public FichothequeQuery toFichothequeQuery() {
        List<FicheQuery> immutableFicheQueryList = SelectionUtils.wrap(ficheQueryList.toArray(new FicheQuery[ficheQueryList.size()]));
        List<MotcleQuery> immutableMotcleQueryList = SelectionUtils.wrap(motcleQueryList.toArray(new MotcleQuery[motcleQueryList.size()]));
        return new InternalFichothequeQuery(immutableFicheQueryList, immutableMotcleQueryList);
    }

    public static FichothequeQueryBuilder init() {
        return new FichothequeQueryBuilder();
    }


    private static class InternalFichothequeQuery implements FichothequeQuery {

        private final List<FicheQuery> ficheQueryList;
        private final List<MotcleQuery> motcleQueryList;

        private InternalFichothequeQuery(List<FicheQuery> ficheQueryList, List<MotcleQuery> motcleQueryList) {
            this.ficheQueryList = ficheQueryList;
            this.motcleQueryList = motcleQueryList;
        }

        @Override
        public List<FicheQuery> getFicheQueryList() {
            return ficheQueryList;
        }

        @Override
        public List<MotcleQuery> getMotcleQueryList() {
            return motcleQueryList;
        }

    }

}
