/* FichothequeLib_Tools - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.selection;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import net.fichotheque.SubsetKey;
import net.fichotheque.album.Album;
import net.fichotheque.selection.CroisementCondition;
import net.fichotheque.selection.IllustrationQuery;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class IllustrationQueryBuilder {

    private final Set<SubsetKey> subsetKeySet = new LinkedHashSet();
    private final Set<String> dimNameSet = new LinkedHashSet();
    private CroisementCondition croisementCondition;

    public IllustrationQueryBuilder() {
    }

    public IllustrationQueryBuilder setCroisementCondition(CroisementCondition croisementCondition) {
        this.croisementCondition = croisementCondition;
        return this;
    }

    public IllustrationQueryBuilder addAlbum(SubsetKey subsetKey) {
        if (!subsetKey.isAlbumSubset()) {
            throw new IllegalArgumentException("!subsetKey.isAlbumSubset()");
        }
        subsetKeySet.add(subsetKey);
        return this;
    }

    public IllustrationQueryBuilder addAlbum(SubsetKey[] subsetKeyArray) {
        for (SubsetKey subsetKey : subsetKeyArray) {
            addAlbum(subsetKey);
        }
        return this;
    }

    public IllustrationQueryBuilder addAlbum(Collection<SubsetKey> subsetKeys) {
        for (SubsetKey subsetKey : subsetKeys) {
            addAlbum(subsetKey);
        }
        return this;
    }

    public IllustrationQueryBuilder addAlbum(Album album) {
        subsetKeySet.add(album.getSubsetKey());
        return this;
    }

    public IllustrationQueryBuilder addAlbumDimName(String albumDimName) {
        dimNameSet.add(albumDimName);
        return this;
    }

    public IllustrationQuery toIllustrationQuery() {
        List<SubsetKey> subsetKeyList = FichothequeUtils.wrap(subsetKeySet.toArray(new SubsetKey[subsetKeySet.size()]));
        List<String> dimNameList = StringUtils.toList(dimNameSet);
        return new InternalIllustrationQuery(subsetKeyList, croisementCondition, dimNameList);
    }

    public static IllustrationQueryBuilder init() {
        return new IllustrationQueryBuilder();
    }


    private static class InternalIllustrationQuery implements IllustrationQuery {

        private final List<SubsetKey> albumKeyList;
        private final CroisementCondition croisementCondition;
        private final List<String> dimNameList;

        private InternalIllustrationQuery(List<SubsetKey> subsetKeyList, CroisementCondition croisementCondition, List<String> dimNameList) {
            this.albumKeyList = subsetKeyList;
            this.croisementCondition = croisementCondition;
            this.dimNameList = dimNameList;
        }

        @Override
        public List<SubsetKey> getAlbumKeyList() {
            return albumKeyList;
        }

        @Override
        public List<String> getAlbumDimNameList() {
            return dimNameList;
        }

        @Override
        public CroisementCondition getCroisementCondition() {
            return croisementCondition;
        }

    }

}
